import time
from calendar import monthrange

from netforce.model import Model,fields,get_model
from netforce.access import get_active_company
from . import utils

class ReportMedicalSummary(Model):
    _name="clinic.report.medical.summary"
    _string="Report Medical Summary"
    _transient=True
    
    _fields={
        "date": fields.Date("Month", required=True),
    }

    _defaults={
        'date': lambda *a: time.strftime("%Y-%m-%d"),
    }
    
    def get_report_data(self,ids,context={}):
        date=time.strftime("%Y-%m-%d")
        defaults=context.get('defaults')
        if defaults:
            date=defaults['date']
        year=int(date[0:4])
        month=int(date[5:7])
        weekday, total_day=monthrange(year, month)

        dom=[]
        dom.append([['state','=','completed']])
        dom.append([['time_start','>=','%s-%s-01 00:00:00'%(year,month)]])
        dom.append([['time_stop','<=','%s-%s-%s 23:59:59'%(year,month,total_day)]])
        
        products={}
        for prod in get_model("product").search_browse([['type','=','stock']]):
            products[prod.code]={}
            for patient_type in ('sc','nhso','personal'):
                products[prod.code][patient_type]={
                    'qty': 0,
                    'name': prod.name,
                    'code': prod.code,
                    'prod_id': prod.id,
                    }
            
        for hd_case in get_model('clinic.hd.case').search_browse(dom):
            patient_type=hd_case.patient_id.type
            for line in hd_case.lines:
                prod=line.product_id 
                if line.type=='fee' or prod.type=='service':
                    continue
                products[prod.code][patient_type]['qty']+=line.qty

        lines=[]
            
        for prod, records in products.items():
            line={
                'prod_name': records['sc']['name'], # XXX
                'prod_id': records[patient_type]['prod_id'],
            }
            for patient_type in ('sc','nhso','personal'):
                line.update({
                    patient_type: records[patient_type]['qty'],
                })
            lines.append(line)

        company_id=get_active_company()
        company=get_model('company').browse(company_id)
        month_str=utils.MONTHS['th_TH'][month]

        lines=sorted(lines, key=lambda x: x['prod_name'])
        titles={
            'prod_name': 'ชื่อยา',
            'sc': utils.PATIENT_TYPE['sc'],
            'nhso': utils.PATIENT_TYPE['nhso'],
            'personal': utils.PATIENT_TYPE['personal'],
            }
        data={
            'company_name': company.name or "",
            'parent_company_name': company.parent_id.name or "",
            'titles': titles,
            'lines': lines,
            'month': month_str,
            'year': year,
        }
        data.update(titles)

        return data

ReportMedicalSummary.register()
