from datetime import datetime, timedelta

from netforce.model import Model, fields, get_model
from netforce.access import get_active_company

class Schedule(Model):
    _name="clinic.schedule"
    _string="Schedule"
    #_field_name="cycle_id"
    
    def _get_name(self,ids,context={}):
        res={}
        for obj in self.browse(ids):
            total_nurse=len(obj.nurses)
            res[obj.id]='%s, Nurse: %s'%(obj.cycle_id.name or "", total_nurse)
        return res

    _fields={
        "name": fields.Char("Name",function="_get_name"),
        'cycle_id': fields.Many2One("clinic.cycle","Cycle",required=True),
        "time_start": fields.DateTime("Time Start",required=True),
        "time_stop": fields.DateTime("Time Stop",required=True),
        'company_id': fields.Many2One("company","Company"),
        'nurses': fields.Many2Many('clinic.personal','Nurses'), # XXX domain
        'state': fields.Selection([['draft','Draft'],['confirmed', 'Confirmed']],'State'),
    }

    _defaults={
        "company_id": lambda *a: get_active_company(),
        'time_start': lambda *a: datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
        'time_stop': lambda *a: (datetime.now()+timedelta(seconds=3600)).strftime("%Y-%m-%d %H:%M:%S"),
        'state': 'draft',
    }

    def confirm(self,ids,context={}):
        obj=self.browse(ids)[0]
        obj.write({
            'state': 'confirmed',
        })

    def to_draft(self,ids,context={}):
        obj=self.browse(ids)[0]
        obj.write({
            'state': 'draft',
        })
        
    
    def view_cycle_item(self,ids,context={}):
        obj=self.browse(ids)[0]
        item_id=get_model("clinic.cycle.item").search([['cycle_id','=',obj.cycle_id.id],['date','=',obj.time_start[0:10]]])
        msg=''
        if not item_id:
            # XXX
            item_id=get_model("clinic.cycle.item").create({
                'cycle_id': obj.cycle_id.id,
                'date': obj.time_start[0:10],
            })
            #raise Exception("No found cycle item")
            item_nurse_obj=get_model("clinic.cycle.item.nurse")
            for nurse in obj.nurses:
                item_nurse_obj.create({
                    'cycle_item_id': item_id,
                    'nurse_id': nurse.id,
                    'level_id': nurse.level_id.id,
                })
            msg='Create Cycle Item successfully'
        return {
            'next': {
                'name': 'clinic_cycle_item',
                'mode': 'form',
                'active_id': item_id,
            },
            'flash': msg,
        }


Schedule.register()
